public final class ImGuiWindowClass
extends java.lang.Object
| Constructor and Description |
|---|
ImGuiWindowClass()
This class will create a native structure.
|
| Modifier and Type | Method and Description |
|---|---|
void |
destroy() |
int |
geClassId()
User data.
|
boolean |
getDockingAllowUnclassed()
Set to true to allow windows of this class to be docked/merged with an unclassed window.
|
boolean |
getDockingAlwaysTabBar()
Set to true to enforce single floating windows of this class always having their own docking node
(equivalent of setting the global io.ConfigDockingAlwaysTabBar)
|
int |
getDockNodeFlagsOverrideClear()
[EXPERIMENTAL]
|
int |
getDockNodeFlagsOverrideSet()
[EXPERIMENTAL] Dock node flags to set when a window of this class is hosted by a dock node (it doesn't have to be selected!)
|
int |
getParentViewportId()
Hint for the platform back-end.
|
void |
setClassId(int classId)
User data.
|
void |
setDockingAllowUnclassed(boolean dockingAllowUnclassed)
Set to true to allow windows of this class to be docked/merged with an unclassed window.
|
void |
setDockingAlwaysTabBar(boolean dockingAlwaysTabBar)
Set to true to enforce single floating windows of this class always having their own docking node
(equivalent of setting the global io.ConfigDockingAlwaysTabBar)
|
void |
setDockNodeFlagsOverrideClear(int dockNodeFlagsOverrideClear)
[EXPERIMENTAL]
|
void |
setDockNodeFlagsOverrideSet(int dockNodeFlagsOverrideSet)
[EXPERIMENTAL] Dock node flags to set when a window of this class is hosted by a dock node (it doesn't have to be selected!)
|
void |
setParentViewportId(int parentViewportId)
Hint for the platform back-end.
|
public ImGuiWindowClass()
destroy() method to manually free used memory.public void destroy()
public int geClassId()
public void setClassId(int classId)
public int getParentViewportId()
<>child relationship between the platform windows.
Not conforming back-ends are free to e.g. parent every viewport to the main viewport or not.public void setParentViewportId(int parentViewportId)
<>child relationship between the platform windows.
Not conforming back-ends are free to e.g. parent every viewport to the main viewport or not.public int getDockNodeFlagsOverrideSet()
public void setDockNodeFlagsOverrideSet(int dockNodeFlagsOverrideSet)
public int getDockNodeFlagsOverrideClear()
public void setDockNodeFlagsOverrideClear(int dockNodeFlagsOverrideClear)
public boolean getDockingAlwaysTabBar()
public void setDockingAlwaysTabBar(boolean dockingAlwaysTabBar)
public boolean getDockingAllowUnclassed()
public void setDockingAllowUnclassed(boolean dockingAllowUnclassed)